@@ -2,7 +2,7 @@
 """ Example of definition of a bore field using custom borehole positions.
 
 """
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 import pygfunction as gt
 
