@@ -12,7 +12,7 @@ from .networks import network_thermal_resistance
 
 
 def uniform_heat_extraction(boreholes, time, alpha, use_similarities=True,
-                            disTol=0.1, tol=1.0e-6, processes=None,
+                            disTol=0.01, tol=1.0e-6, processes=None,
                             disp=False):
     """
     Evaluate the g-function with uniform heat extraction along boreholes.
@@ -32,10 +32,10 @@ def uniform_heat_extraction(boreholes, time, alpha, use_similarities=True,
         True if similarities are used to limit the number of FLS evaluations.
         Default is True.
     disTol : float, optional
-        Absolute tolerance (in meters) on radial distance. Two distances
+        Relative tolerance on radial distance. Two distances
         (d1, d2) between two pairs of boreholes are considered equal if the
         difference between the two distances (abs(d1-d2)) is below tolerance.
-        Default is 0.1.
+        Default is 0.01.
     tol : float, optional
         Relative tolerance on length and depth. Two lengths H1, H2
         (or depths D1, D2) are considered equal if abs(H1 - H2)/H2 < tol.
@@ -77,7 +77,7 @@ def uniform_heat_extraction(boreholes, time, alpha, use_similarities=True,
     # Initialize heat extraction rates
     Q = np.ones(nBoreholes)
     # Initialize g-function
-    gFunction = np.zeros_like(np.atleast_1d(time))
+    gFunction = np.zeros(nt)
     # Borehole lengths
     H = np.array([b.H for b in boreholes])
 
@@ -111,7 +111,7 @@ def uniform_heat_extraction(boreholes, time, alpha, use_similarities=True,
 
 
 def uniform_temperature(boreholes, time, alpha, nSegments=12, method='linear',
-                        use_similarities=True, disTol=0.1, tol=1.0e-6,
+                        use_similarities=True, disTol=0.01, tol=1.0e-6,
                         processes=None, disp=False):
     """
     Evaluate the g-function with uniform borehole wall temperature.
@@ -140,10 +140,10 @@ def uniform_temperature(boreholes, time, alpha, nSegments=12, method='linear',
         True if similarities are used to limit the number of FLS evaluations.
         Default is True.
     disTol : float, optional
-        Absolute tolerance (in meters) on radial distance. Two distances
+        Relative tolerance on radial distance. Two distances
         (d1, d2) between two pairs of boreholes are considered equal if the
         difference between the two distances (abs(d1-d2)) is below tolerance.
-        Default is 0.1.
+        Default is 0.01.
     tol : float, optional
         Relative tolerance on length and depth. Two lengths H1, H2
         (or depths D1, D2) are considered equal if abs(H1 - H2)/H2 < tol.
@@ -191,7 +191,7 @@ def uniform_temperature(boreholes, time, alpha, nSegments=12, method='linear',
     # Number of time values
     nt = len(np.atleast_1d(time))
     # Initialize g-function
-    gFunction = np.zeros_like(np.atleast_1d(time))
+    gFunction = np.zeros(nt)
     # Initialize segment heat extraction rates
     Q = np.zeros((nSources, nt))
 
@@ -273,7 +273,7 @@ def uniform_temperature(boreholes, time, alpha, nSegments=12, method='linear',
 
 def equal_inlet_temperature(boreholes, UTubes, m_flow, cp, time, alpha,
                             method='linear', nSegments=12,
-                            use_similarities=True, disTol=0.1, tol=1.0e-6,
+                            use_similarities=True, disTol=0.01, tol=1.0e-6,
                             processes=None, disp=False):
     """
     Evaluate the g-function with equal inlet fluid temperatures.
@@ -308,10 +308,10 @@ def equal_inlet_temperature(boreholes, UTubes, m_flow, cp, time, alpha,
         True if similarities are used to limit the number of FLS evaluations.
         Default is True.
     disTol : float, optional
-        Absolute tolerance (in meters) on radial distance. Two distances
+        Relative tolerance on radial distance. Two distances
         (d1, d2) between two pairs of boreholes are considered equal if the
         difference between the two distances (abs(d1-d2)) is below tolerance.
-        Default is 0.1.
+        Default is 0.01.
     tol : float, optional
         Relative tolerance on length and depth. Two lengths H1, H2
         (or depths D1, D2) are considered equal if abs(H1 - H2)/H2 < tol.
@@ -359,7 +359,7 @@ def equal_inlet_temperature(boreholes, UTubes, m_flow, cp, time, alpha,
     # Number of time values
     nt = len(np.atleast_1d(time))
     # Initialize g-function
-    gFunction = np.zeros_like(np.atleast_1d(time))
+    gFunction = np.zeros(nt)
     # Initialize segment heat extraction rates
     Q = np.zeros((nSources, nt))
 
@@ -468,7 +468,7 @@ def equal_inlet_temperature(boreholes, UTubes, m_flow, cp, time, alpha,
 
 def mixed_inlet_temperature(network, m_flow, cp,
                             time, alpha, method='linear', nSegments=12,
-                            use_similarities=True, disTol=0.1, tol=1.0e-6,
+                            use_similarities=True, disTol=0.01, tol=1.0e-6,
                             processes=None, disp=False):
     """
     Evaluate the g-function with mixed inlet fluid temperatures.
@@ -505,10 +505,10 @@ def mixed_inlet_temperature(network, m_flow, cp,
         True if similarities are used to limit the number of FLS evaluations.
         Default is True.
     disTol : float, optional
-        Absolute tolerance (in meters) on radial distance. Two distances
+        Relative tolerance on radial distance. Two distances
         (d1, d2) between two pairs of boreholes are considered equal if the
         difference between the two distances (abs(d1-d2)) is below tolerance.
-        Default is 0.1.
+        Default is 0.01.
     tol : float, optional
         Relative tolerance on length and depth. Two lengths H1, H2
         (or depths D1, D2) are considered equal if abs(H1 - H2)/H2 < tol.
@@ -567,7 +567,7 @@ def mixed_inlet_temperature(network, m_flow, cp,
     # Number of time values
     nt = len(np.atleast_1d(time))
     # Initialize g-function
-    gFunction = np.zeros_like(np.atleast_1d(time))
+    gFunction = np.zeros(nt)
     # Initialize segment heat extraction rates
     Q = np.zeros((nSources, nt))
 
