@@ -544,7 +544,7 @@ class _BasePipe(object):
         from matplotlib.ticker import AutoMinorLocator
 
         # Initialize figure
-        LW = 1.5    # Line width
+        LW = .5    # Line width
         FS = 12.    # Font size
 
         plt.rc('figure', figsize=(80.0/25.4, 80.0/25.4))
@@ -638,6 +638,67 @@ class _BasePipe(object):
             check = False
 
         return check
+    
+    def _check_geometry(self):
+        """ Verifies the inputs to the pipe object and raises an error if
+            the geometry is not valid.
+        """
+        # Verify that thermal properties are greater than 0.
+        if not self.k_s > 0.:
+            raise ValueError(
+                'The ground thermal conductivity must be greater than zero. '
+                'A value of {} was provided.'.format(self.k_s))
+        if not self.k_g > 0.:
+            raise ValueError(
+                'The grout thermal conductivity must be greater than zero. '
+                'A value of {} was provided.'.format(self.k_g))
+        if not self.R_fp > 0.:
+            raise ValueError(
+                'The fluid to outer pipe wall thermal resistance must be'
+                'greater than zero. '
+                'A value of {} was provided.'.format(self.R_fp))
+
+        # Verify that the pipe radius is greater than zero.
+        if not self.r_in > 0.:
+            raise ValueError(
+                'The pipe inner radius must be greater than zero. '
+                'A value of {} was provided.'.format(self.r_in))
+
+        # Verify that the outer pipe radius is greater than the inner pipe
+        # radius.
+        if not self.r_out > self.r_in:
+            raise ValueError(
+                'The pipe outer radius must be greater than the pipe inner'
+                ' radius. '
+                'A value of {} was provided.'.format(self.r_out))
+
+        # Verify that the number of multipoles is zero or greater.
+        if not self.J >= 0:
+            raise ValueError(
+                'The number of terms in the multipole expansion must be zero'
+                ' or greater. '
+                'A value of {} was provided.'.format(self.J))
+
+        # Verify that the pipes are contained within the borehole.
+        for i in range(2*self.nPipes):
+            r_pipe = np.sqrt(self.pos[i][0]**2 + self.pos[i][1]**2)
+            if not r_pipe + self.r_out <= self.b.r_b:
+                raise ValueError(
+                    'Pipes must be entirely contained within the borehole. '
+                    'Pipe {} is partly or entirely outside the '
+                    'borehole.'.format(i))
+
+        # Verify that the pipes do not collide to one another.
+        for i in range(2*self.nPipes):
+            for j in range(i+1, 2*self.nPipes):
+                dx = self.pos[i][0] - self.pos[j][0]
+                dy = self.pos[i][1] - self.pos[j][1]
+                dis = np.sqrt(dx**2 + dy**2)
+                if not dis >= 2*self.r_out:
+                    raise ValueError(
+                        'Pipes {} and {} are overlapping.'.format(i, j))
+
+        return True
 
     def _continuity_condition_base(self, m_flow, cp, nSegments):
         """ Returns coefficients for the relation
@@ -742,6 +803,7 @@ class SingleUTube(_BasePipe):
         self.nPipes = 1
         self.nInlets = 1
         self.nOutlets = 1
+        self._check_geometry()
 
         # Delta-circuit thermal resistances
         self._Rd = thermal_resistances(pos, r_out, borehole.r_b,
@@ -1130,6 +1192,7 @@ class MultipleUTube(_BasePipe):
         self.nInlets = 1
         self.nOutlets = 1
         self.config = config.lower()
+        self._check_geometry()
 
         # Delta-circuit thermal resistances
         self._Rd = thermal_resistances(pos, r_out, borehole.r_b,
@@ -1554,6 +1617,7 @@ class IndependentMultipleUTube(MultipleUTube):
         self.nPipes = nPipes
         self.nInlets = nPipes
         self.nOutlets = nPipes
+        self._check_geometry()
 
         # Delta-circuit thermal resistances
         self._Rd = thermal_resistances(pos, r_out, borehole.r_b,
